@@ -36,6 +36,8 @@ class Client:
         self.client_uuid                = client_uuid
 
         self.__google_clients           = GoogleClients.ApiClients(credentials_file_path)
+        logging_client                  = self.__google_clients.cloud_logging_client
+        self.__client_ops_logger        = logging_client.logger(client_uuid + '-file-logger')
         self.__argument_validator       = Argument.Validator(self.__google_clients)
         self.__upload_file              = Upload.Client(self.__google_clients, client_uuid)
         self.__insert_patient           = Insert.Client(self.__google_clients, client_uuid)
@@ -77,10 +79,14 @@ class Client:
         
         classified_modality = self.__document_classifier_operations(mrn, file_path)
         if not classified_modality:
+            classified_modality = 'Failed To Classify'
             warnings.warn("Request to document classifier failed.")
+            self.__client_ops_logger.log_text('failed to run document classifier on file ' + file_path, severity='WARNING')
         elif classified_modality != modality:
             Helpers.print_error("Modality may be incorrect. Modality might be " + classified_modality)
-        
+
+        file_metadata['CLASSIFIED_MODALITY'] = classified_modality
+
         # run command
         return self.__upload_file.upload_file_to_datalake(
             modality, mrn, file_metadata, file_path)
