@@ -42,6 +42,8 @@ class Client:
         '''
         self.client_uuid                = client_uuid
         self.__google_storage_client    = google_clients.cloud_storage_client
+        logging_client                   = google_clients.cloud_logging_client
+        self.__file_upload_logger       = logging_client.logger(client_uuid + '-file-logger')
         self.__patients_table_client    = Insert.Client(
             google_clients, self.client_uuid)
         self.__changelog_client         = ChnglogInsert.Client(
@@ -96,6 +98,7 @@ class Client:
 
         if Helpers.try_blob_exists(blob):
             Helpers.print_error("File" + blob.name + " already exists")
+            self.__file_upload_logger.log_text("File" + blob.name + " already exists", severity='INFO')
             return True
 
         if not self.__create_blob_with_metadata(blob, file_contents, metadata):
@@ -180,6 +183,12 @@ class Client:
 
         if Helpers.try_blob_exists(blob):
             print('successfully uploaded file to datalake')
+            self.__file_upload_logger.log_text('successfully uploaded file ' + blob.name + ' to datalake', severity='INFO')
+            if metadata['MODALITY'] != metadata['CLASSIFIED_MODALITY']:
+                self.__file_upload_logger.log_text('Classified Modality for ' 
+                    + blob.name + ' (' + metadata['CLASSIFIED_MODALITY'] + 
+                    ') does not matched metadata supplied (' + metadata['MODALITY'] + ')', severity='WARNING')
+
             return True
 
         return False
@@ -249,4 +258,6 @@ class Client:
             return True
         except Exception as e:
             Helpers.print_error("Could not upload blob " + str(e))
+            self.__file_upload_logger.log_text('Failed To Upload Blob ' 
+                + blob.name + ' using GCS client: ' + str(e), severity='ERROR')
             return False
\ No newline at end of file
