@@ -108,7 +108,8 @@ class Client:
     def __insert_multiple_patients_to_table(self, json_structure, overwrite=False):
         '''
             loops through json structure and inserts all patients into the PATIENTS
-            table
+            table, if a patient is not successfully uploaded then it is logged and
+            the process continues.
             Args:
                 json_structure (dict[]): list of dictionarys containing the patients data
                 overwrite (boolean): Flag to indicate whether or not the row needs to get
@@ -116,12 +117,20 @@ class Client:
             Returns:
                 boolean: True if the operation was a success False if otherwise
         '''
+        status = True
         for i in json_structure:
             if self.__insert_patient_to_patients_table(i, overwrite=overwrite):
                 continue
             else:
-                return False
-        return True
+                status = False
+
+        if status == False:
+            self.__patient_insert_logger.log_text(
+                'One or more patients have not been uploaded Successfully', severity='ERROR')
+
+        self.__patient_insert_logger.log_text(
+            'All patients have been uploaded Successfully', severity='INFO')
+        return status
 
 
     def __insert_patient_to_patients_table(self, patient_data, overwrite=False):
@@ -236,6 +245,8 @@ class Client:
         # serialized_rows repeated field.
         
         serialized_row  = self.__create_proto_buf_row(patient_data)
+        if serialized_row is None:
+            return False
         response_future_1 = self.__big_query_wrapper.insert_to_bq_table(
             self.__google_big_query_storage_client, serialized_row, request_template, stream_name, parent)
         
@@ -267,7 +278,12 @@ class Client:
             if field in patient_data:
                 row = self.__proto_buf_dictionary[field](row, patient_data[field])
 
-        return row.SerializeToString()
+        try:
+            return row.SerializeToString()
+        except Exception as e:
+            self.__patient_insert_logger.log_text("error creating protocol buffer " + str(e),
+            severity='ERROR')
+            return None
         
         
     def __insert_client_id(self, row, client_id):
