@@ -180,20 +180,25 @@ class Client:
                 True if a patient needs to be updated, false if otherwise.
         '''
 
+        status=True
+        
+        if self.overwrite == True:
+            return True
+
         if self.__compare_checksum(patient_data, patient_row):
             print("No Changes in Checksum")
             return False
 
-        # compare, if a single value in patient data
+        # compare, the changes in the two records
         for k in patient_data:
             if k == "CLIENT_ID" or k == "MRN" or k == "PATIENT_ID" or k == "UPDATED_AT":
                 continue
             
-            elif self.__is_new_data(patient_data[k], patient_row.get(k)) or self.overwrite==True:
-                return True
+            elif not self.__is_updateable(patient_data[k], patient_row.get(k)):
+                status = False
 
-        # nothing to update no need to make API call
-        return False
+
+        return status
 
     
     def __compare_checksum(self, patient_data, patient_row):
@@ -214,26 +219,37 @@ class Client:
         return False
 
 
-    def __is_new_data(self, input_value, existing_value):
+    def __is_updateable(self, input_value, existing_value):
         '''
             Function that checks whether or not there is new data in the
-            json passed for a patient
+            json passed for a patient. If the the values are the same True is returned. 
             Args:
                 patient_json_value (string): The value of the patient json data passed in
                 existing_value  (string): The value already existing in the PATIENTS table
             Returns:
                 boolean: True if there is more data passed, False if not
         '''
+        if input_value is None and existing_value is None:
+            # no values, is updateable
+            return True
+
+        if input_value is None and existing_value is not None and self.overwrite == False:
+            # no trying to replace value this none, not updateable
+            return False
 
         if input_value is not None and existing_value is None:
-            # can update the file
+            # can update the patient
             print(input_value, existing_value)
             return True
             
         if input_value is not None and existing_value is not None and self.overwrite == False:
             if input_value == existing_value:
-                return False
+                # no change here
+                return True
+            # different values cannot overwrite, not updateable
             print_error("Cannot overide values in the PATIENT table using this command," +
             " try patients-table update command instead.")
+            return False
         
-        return False
\ No newline at end of file
+        # default changeable
+        return True
\ No newline at end of file
